stalker.core.mixins — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.mixins

`stalker.core.` `mixins`

  This module contains the Mixins (ta taaa).

  Mixins are, you know, things that we love. Ok I don’t have anything to write, just use and love them.

  For SQLAlchemy part of the mixins (tables and mappers) refer to the `mixin`. There is a corresponding helper class for every mixin implemented in this module. Also the documentation explains how to mixin tables and mappers.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »